	***********************************************************************************
	* Replication do-file for "Geopolitics, Aid and Growth"
	* Dreher, Eichenauer & Gehring 2016, WBER
	***********************************************************************************
	
	version 13.0
	drop _all
	clear
	clear matrix
	clear mata
	set mem 2000m
	set mat 1000

	**** Set the directory **********************************************
	local DIR = "C:\Users\gehring\Dropbox\Aid,Security Council and growth\Submissions\WBER\Final version and data\Geopolitics, Aid and Growth_replication\Data "  /*Insert the path in which you copied the data*/
	cd  "`DIR'"	
	
	* Necessary stata programs
	/*
	capture net install egenmore, from(http://fmwww.bc.edu/RePEc/bocode/e)		/* checks whether egenmore is installed		*/
	capture net install estout, from(http://fmwww.bc.edu/RePEc/bocode/e)		/* checks whether estout is installed		*/
	capture net install spmon, from(http://fmwww.bc.edu/RePEc/bocode/s)			/* checks whether spmon is installed		*/
	capture net install mmerge, from(http://fmwww.bc.edu/RePEc/bocode/m)		/* checks whether mmerge is installed		*/
	capture net install msp, from(http://fmwww.bc.edu/RePEc/bocode/m)			/* checks whether msp is installed			*/
	*/

***********************************************************************************
** PROGRAMS FOR PREPPING AID, POLICY AND OTHER VARIABLES & Robustness checks
***********************************************************************************
	set more off
	do "sub dofile\programs_final_replication.do" 

* Log
	*capture log using "tables\Dreher Eichenauer Gehring.log", replace
	

*** checks whether folder "processed" (where transformed data are stored) and "tables" (where tables are stored) exist and creates it if not
	program define confirmdir, rclass
		local cwd `"`c(pwd)'"'
		quietly capture cd `"`1'"'
		local confirmdir=_rc 
		quietly cd `"`cwd'"'
		return local confirmdir `"`confirmdir'"'
	end 
		confirmdir `"tables"'		  /* does folder "tables" exist? */
			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
				mkdir "tables"  /* makes the folder  */
							  } 
			  else {
				di "folder tables already exists"
				}
	program drop confirmdir

**************************************************************************************************************************************************************************************
*********  Graphs 2-4
**************************************************************************************************************************************************************************************

***************************************************************************************************************************************************************************************
** Graph 2: UNSC and Aid commitments for all donors
***************************************************************************************************************************************************************************************
 use "data processed\data_graph1.dta", clear
graph bar (max) Podacom0 (max) Podacom5  (max) Podacom1 (max) Podacom2 (max) Podacom4 if hic!=1 & code~="CHN" & code~="RUS" & year>1959 & SUNSC!=3 ,  showyvars ///
  bar(1, fcolor(gs14) lcolor(black)) bar(2, fcolor(gs10) lcolor(black)) bar(3, fcolor(gs1) lcolor(black)) bar(4, fcolor(gs1) lcolor(black)) ///
    bar(5, fcolor(gs7) lcolor(black)) yvaroptions(relabel( 1 "No UNSC member" 2 "UNSC (t-3)" 3 "One year (t-2)" 4 "Two years (t-2)" 5 "UNSC (t-1)") label(labsize(small)))    ///
   title()  blabel(bar, format(%9.0f)) ylabel(,labsize(small) nogrid) ///
   legend(on) scheme(s1color  ) graphregion(fcolor(white) ifcolor(white))  bargap(60) outergap (25) ///
 plotregion(fcolor(white) lstyle(none))  ytitle("Aggregated aid from DAC donors" "Constant 2000 US$ (in million)", margin( mediumsmall) size(small)) legend(off) ///
 b1title("4-year periods, 1959-2009, excluding Russia and China " "61 never members, 87 members", justification(centered) size( small))

 graph save "tables\Figure2_UNSC&AIDcomall", replace
                    graph export                      "tables\Figure2_UNSC&AIDcomall.tif", replace width(800)
graph save "tables\Figure2_UNSC&AIDcomall", replace
graph export                      "tables\Figure2_UNSC&AIDcomall.eps", replace 		preview(on)
					
***************************************************************************************************************************************************************************************
*  Graph 3: UNSC and Aid disbursements for all DAC donors
***************************************************************************************************************************************************************************************
use "data processed\data_graph2.dta", clear
graph bar (max) Podadis0 (max) Podadis5  (max) Podadis1 (max) Podadis2 (max) Podadis4 if hic!=1 & code~="CHN" & code~="RUS" & year>1959 & PUNSC!=3 ,  showyvars ///
  bar(1, fcolor(gs14) lcolor(black)) bar(2, fcolor(gs10) lcolor(black)) bar(3, fcolor(gs1) lcolor(black)) bar(4, fcolor(gs1) lcolor(black)) ///
   bar(5, fcolor(gs7) lcolor(black)) yvaroptions(relabel( 1 "No UNSC member" 2 "UNSC (t-2)" 3 "One year (t-1)" 4 "Two years (t-1)" 5 "UNSC (t)") label(labsize(small)))    ///
   title()  blabel(bar, format(%9.0f))  ylabel(,labsize(small) nogrid)  ///
    legend(on) scheme(s1color) graphregion(fcolor(white) ifcolor(white))  bargap(60) outergap (25) ///
 plotregion(fcolor(white) lstyle(none))  ytitle("Aggregated aid from DAC donors" "Constant 2000 US$ (in million)", margin( mediumsmall) size(small)) legend(off) ///
 b1title("4-year periods, 1959-2009, excluding Russia and China." "61 never members, 87 members", justification(centered) size( small))
 graph save "tables\Figure3_UNSC&AIDdisball", replace
 graph export                      "tables\Figure3_UNSC&AIDdisball.tif",  replace  	
graph save "tables\Figure3_UNSC&AIDdisball", replace
 graph export                      "tables\Figure3_UNSC&AIDdisball.eps",  replace  preview(on)			

***************************************************************************************************************************************************************************************
** Graph 4: Mean growth in periods around UNSC membership 
***************************************************************************************************************************************************************************************
use "data processed\data_graph3.dta", clear
graph bar (mean) mgrowth0 (mean) m1growth (mean) mgrowth1 (mean) mgrowth2  (mean) mgrowth3  (mean) mgrowth4, showyvars  ///
bar(1, fcolor(gs16) lcolor(black)) bar(2, fcolor(gs4) lcolor(black)) bar(3, fcolor(gs6) lcolor(black)) bar(4, fcolor(gs8) lcolor(black)) /// 
bar(5, fcolor(gs1) lcolor(black)) bar(6, fcolor(gs10) lcolor(black)) ///
bargap(25) outergap(25) title() blabel(bar, format(%9.2f))   nolabel legend(off) ///
yvaroptions(relabel(1 "No UNSC member" 2 "UNSC (t-3)" 3 "UNSC (t-2)" 4 "UNSC (t-1)" 5 "UNSC (t)" 6 "UNSC (t+1)")label(labsize(small))) ///
 graphregion(fcolor(white) ifcolor(white))  plotregion(fcolor(white)) ytitle("GDP per capita growth rate")
 graph save "tables\Figure4_UNSC&growth", replace
   graph export                      "tables\Figure4_UNSC&growth.eps",  replace   preview(on)	
  
****************************************************************************************************************************************************
*********************  Regressions *****************************************************************************************************************
****************************************************************************************************************************************************
*************************************************************************
*** Burnside and Dollar Specification, Extended Years 1970-2009 ***
*************************************************************************
global if if bdsamp==1 & periodst>=1970 & llShareUNSC!=.   //See sub-programs and BD 2001 paper.
use "data processed\BD_replicated2.dta", clear

tsset ccode periodendBD,delta(4) //four year periods
aidstat
cap rename policy_newper _policy_newper   //This calls a sub-program that creates the control variables used in the BD 2001

* Main variables
gen ShareUNSC=ShareUNSCBD  //Share of years out of your year periods as UNSC member"
label var ShareUNSC "Share of years a country spend in the UNSC out of period (t)"
gen Aid = ODA
label var Aid "Net ODA as a share of GDP (t)"
gen lAid = l.ODA
label var lAid "Net ODA as a share of GDP (t-1)"

* Generate Aid variables
gen Aid2 = Aid^2  
label var Aid2 "Squared term of  net ODA as a share of GDP (t)"       
gen lAid2 = l.Aid2
label var lAid2 "Squared term of  net ODA as a share of GDP (t-1)"  
gen dlAid = d.l.Aid 
label var dlAid "Difference in net ODA as a share of GDP (t-1) - (t-2)" 
gen dlAid2 = d.l.Aid2 
label var dlAid2 "Squared difference in net ODA as a share of GDP (t-1) - (t-2)" 
gen dAid=d.Aid 
label var dAid "Squared difference in net ODA as a share of GDP (t-0) - (t-1)"
gen dAid2 = d.Aid2
label var dAid2 "Squared difference in net ODA as a share of GDP (t) - (t-1)" 
gen dllAid=d.l2.Aid
label var dllAid "Difference in net ODA as a share of GDP (t-3) - (t-2)" 
gen dllAid2=d.ll.Aid2
label var dllAid2 "Squared difference in net ODA as a share of GDP (t-2) - (t-3)" 
gen llAid=ll.Aid
label var llAid "Net ODA as a share of GDP (t-2)"
gen fAid=f.Aid
label var fAid "Net ODA as a share of GDP (t+1)"
gen fAid2=f.Aid2
label var fAid2 "Squared Net ODA as a share of GDP (t+1)"

** Interaction Terms
gen AID_UNSC=Aid*ShareUNSC 				//Interaction  I
label var AID_UNSC "Interaction between ODA (t) and share of UNSC membership in period (t)" //disbursements?
gen lShareUNSC=l.ShareUNSC					
label var  lShareUNSC "share of UNSC membership in period (t-1)"
gen llShareUNSC=l.l.ShareUNSC 
label var llShareUNSC "UNSC membership-share in period (t-2)"
gen lllShareUNSC=l.l.l.ShareUNSC					
label var  lllShareUNSC "share of UNSC membership in period (t-3)"
gen fShareUNSC=f.ShareUNSC					
label var  fShareUNSC "share of UNSC membership in period (t+1)"

* Aid in t-1 with UNSC in different periods
gen dlAID_lUNSC=dlAid*lShareUNSC			//Interaction  dAid(t-1) * UNSC(t-1)
label var dlAID_lUNSC "Interaction  dAid(t-1) * UNSC(t-1)"
gen dlAID_llUNSC=dlAid*llShareUNSC			//Interaction  dAid(t-1) * UNSC(t-2)
label var dlAID_llUNSC "Interaction  dAid(t-1) * UNSC(t-2)"
gen dlAID_lllUNSC=dlAid*lllShareUNSC			//Interaction  dAid(t-1) * UNSC(t-3)
label var dlAID_lllUNSC "Interaction  dAid(t-1) * UNSC(t-3)"
gen dlAID_fUNSC=dlAid*fShareUNSC			//Interaction  dAid(t-1) * UNSC(t+1)
label var dlAID_fUNSC "Interaction  dAid(t-1) * UNSC(t+1)"

* Other lag structures for robustness tests, Aid in t-2
gen dllAID_lUNSC=dllAid*lShareUNSC			//Interaction  dAid(t-2) * UNSC(t-1)
label var dllAID_lUNSC "Interaction  dAid(t-2) * UNSC(t-1)"
gen dllAID_llUNSC=dllAid*llShareUNSC			//Interaction  dAid(t-2) * UNSC(t-2)
label var dllAID_llUNSC "Interaction  dAid(t-2) * UNSC(t-2)"
gen dllAID_fUNSC=dllAid*fShareUNSC			//Interaction  dAid(t-2) * UNSC(t+1)
label var dllAID_fUNSC "Interaction  dAid(t-2) * UNSC(t+1)"
 
* Other lag structures for robustness tests, Aid in t, contemporary effect of aid
gen dAID_UNSC=dAid*ShareUNSC			//Interaction  dAid(t) * UNSC(t)
label var dAID_UNSC "Interaction  dAid(t) * UNSC(t)"
gen dAID_lUNSC=dAid*lShareUNSC			//Interaction  dAid(t) * UNSC(t-1)
label var dAID_lUNSC "Interaction  dAid(t) * UNSC(t-1)"
gen dAID_llUNSC=dAid*llShareUNSC			//Interaction  dAid(t) * UNSC(t-2)
label var dAID_llUNSC "Interaction  dAid(t) * UNSC(t-2)"
gen dAID_fUNSC=dAid*fShareUNSC			//Interaction  dAid(t) * UNSC(t+1)
label var dAID_fUNSC "Interaction  dAid(t) * UNSC(t+1)"
gen dlAID_UNSC=dlAid*ShareUNSC 			//Interaction  II
label var dlAID_UNSC "Interaction: dAid in t-1,  UNSC membership-share in period (t)"
gen dllAID_UNSC=dllAid*ShareUNSC 			//Interaction  II
label var dllAID_UNSC "Interaction: dAid in t-2,  UNSC membership-share in period (t)"

* Variables for other specifications
gen AID_fUNSC=Aid*fShareUNSC 			
label var AID_fUNSC "Interaction: Aid in (t), UNSC membership-share  period (t+1)"
gen lAID_lUNSC=lAid*lShareUNSC 			
label var lAID_lUNSC "Interaction: lagged ODA, UNSC membership-share period (t-1)"		
gen lAID_llUNSC=lAid*llShareUNSC 		
label var lAID_llUNSC "Interaction: lagged ODA, UNSC membership-share in period (t-2)"
gen AID_lUNSC=Aid*lShareUNSC
label var AID_lUNSC "Interaction: aid in t, UNSC membership-share in period (t-1)"
gen dlAID2_llUNSC=dlAid2*llShareUNSC
label var dlAID2_llUNSC "difference of squared aid in (t-1)-(t-2), share of UNSC-membership in (t-2)"

** Variables for regressions with UNSC dummy and in first differences
gen D_UNSC=0 
replace D_UNSC=1 if ShareUNSC>0 & ShareUNSC!=./* UNSC dummy*/
label var D_UNSC "Binary variable 1 if UNSC membership in period (t)"
gen D_llUNSC=0 
replace D_llUNSC=1 if llShareUNSC>0 & llShareUNSC!=./* lagged UNSC dummy*/
label var D_llUNSC "Binary variable 1 if UNSC membership in period (t-2)"
gen dlAID_D_llUNSC=d.l.Aid*D_llUNSC 
label var dlAID_D_llUNSC "Interaction: FD Aid in(t-1), Binary variable 1 if UNSC membership in period (t-2)"
gen dllShareUNSC=d.l2.ShareUNSC 
label var dllShareUNSC "FD of Share UNSC(t-2)"
gen dlAID_dllUNSC=d.lAID_llUNSC
label var dlAID_dllUNSC "Interaction: FD Aid in(t-1), FD of Share UNSC(t-2)"


** ICRG variables
forvalues x=1(1)13 {
clonevar lvalue`x'=value`x'
 replace lvalue`x'=L.value`x'
}

* Additional control with commitments
gen lAidcom = l.Aidcom
label var lAidcom "ODA commitments as a share of GDP (t-1)"
gen Aidcom2 = Aidcom^2   
label var Aidcom2 "Squared ODA commitments as a share of GDP (t)"        
gen lAidcom2 = l.Aidcom2
label var lAidcom2 "Squared ODA commitments as a share of GDP (t-1)"  
gen llAidcom = ll.Aidcom   
label var llAidcom "ODA commitments as a share of GDP (t-2)"      
gen llAidcom2 = ll.Aidcom2
label var llAidcom2 "Squared ODA commitments as a share of GDP (t-2)" 
gen dllAidcom=d.llAidcom
label var dllAidcom "FD ODA commitments as a share of GDP (t-2)" 
gen dllComm_llUNSC=dllAidcom*llShareUNSC
label var dllComm_llUNSC "Interaction: FD ODA commitments as a share of GDP (t-2), UNSC membership in period (t-2)" 

** Variables for regression with early impact aid: early impact (gross) and repayments
rename earlyaidC_gdp Earlyaid
label var Earlyaid "Early impact aid/GDP"
gen lEarlyaid = l.Earlyaid
label var lEarlyaid "Early impact aid/GDP (t-1)"
gen lEarlyaid2 = l.Earlyaid*l.Earlyaid
label var lEarlyaid2 "(Early impact aid/GDP)^2 (t-1)"
gen dlEarlyaid_llUNSC=d.lEarlyaid*llShareUNSC
label var dlEarlyaid_llUNSC "Interaction: FD Early impact aid/GDP (t-1), UNSC membership-share in period (t-2)"
label var repay_gdp "Repayment/GDP"
gen lrepay_gdp = l.repay_gdp
label var lrepay_gdp "Repayment/GDP (t-1)"
gen lrepay_gdp2 = l.repay_gdp*l.repay_gdp
label var lrepay_gdp2 "(Repayment/GDP)^2 (t-1)"
gen dlrepay_gdp_llUNSC=d.lrepay_gdp*llShareUNSC
label var dlrepay_gdp_llUNSC "Interaction: FD Repayment/GDP (t-1), UNSC membership-share in period (t-2) "

*BD Conditions
global bd gdppc62_0 ethnofrac assassinations ethnicXassass_post ssa easia institution0 m2finall1 
global period _Iperiod_3 _Iperiod_4 _Iperiod_5 _Iperiod_6 _Iperiod_7 _Iperiod_8 _Iperiod_9 _Iperiod_10
qui reg gdppcg l.Aid $bd lninfl open_ww2 bbfinal $period $if,vce(cluster ccode) 
policyn

***************************************************************************************************************************************************************************************************
************  Descriptive statistics ***************************************************************************************************************************************************************
****************************************************************************************************************************************************************************************************
*label var US "US disbursement in current Prices (USD millions)" // = odadis_USA
*label var ShareUNSCBD "UNSC membership"
label var gdppcg "GDP p.c. growth"
label var ShareUNSC "UNSC membership, % share"
label var D_UNSC "UNSC membership dummy
label var gdppc62_0 "Log Initial GDP/capita"
label var institution0 "Institutional Quality"
label var m2finall1 "M2/GDP"
label var bbfinal "Budget Balance"
label var bdinfl "Inflation"
label var policy_newper "Policy"
label var bdsacw "Openness"
label var ethnofrac  "Ethnolinguistic Franctionalization"
label var ODA "Net ODA/GDP"
label var Aidcom "ODA Commitments/GDP"
label var llDemocracy "Democracy (t-2)"
gen llAutocracy=.
replace llAutocracy=0 if llDemocracy==1
replace llAutocracy=1 if llDemocracy==0
label var llAutocracy "Autocracy (t-2)"
label var imports_gdp "Imports/GDP"
label var unpk_pop "Peacekeeping troops p.c."
label var FDIpGDP  "FDI/GDP"
label var trade_gdp "Trade/GDP"
label var USAid "US Aid/GDP
label var UNGA_INLINE_US "Average Voting Alignment with USA"
label var ethnofrac "Ethnolinguistic Fractionalization"
label variable value1 "Bureaucracy Quality"
label variable value2 "Corruption"
label variable value3 "Democratic Accountability"
label variable value9 "Law & Order"
label variable value11 "Political Risk Rating"
label variable value4 "Ethnic Tensions"
label variable value12 "Religious Tensions"
label variable value10 "Military in Politics"
label variable value7 "Internal Conflict"
label variable value5 "External Conflict"
label variable value6 "Government Stability"
label variable value8 "Investment Profile"
label variable value13 "Socioeconomic Conditions"

 qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper  ) llShareUNSC dlAID_llUNSC   $period $if,vce(cluster ccode)
estpost summarize ODA ShareUNSC D_UNSC gdppcg  gdppc62_0  bbfinal bdinfl   m2finall1 institution0 assassinations ///
  ethnofrac policy_newper bdsacw Aidcom USAid llDemocracy llAutocracy imports_gdp trade_gdp unpk_pop FDIpGDP debt STdebt debt UNGA_INLINE_US value1-value3 ///
	value9 value11 value4 value12 value10 value7 value5 value6 value8 if e(sample) /* to view on screen */
 	
capture noisily esttab using "tables\descriptives log.txt", cells("varlabels(`e(labels)') count mean sd min max") noobs tab label replace /* for export */
***************************************************************************************************************************************************************************************

********************************************************
** Table 1: Full specifications
********************************************************
qui	reg d.(gdppcg) dlAid llShareUNSC dlAID_llUNSC  d.($bd policy_newper  )   $period $if , vce(cluster ccode) 
		estadd local Aidlagged="Yes"
		estadd local FD="Yes"
		estadd local sample="All"
		est store BD_Full1

qui reg d.(gdppcg) dlAid dlAid2 llShareUNSC dlAID_llUNSC  d.( $bd policy_newper  )   $period $if , vce(cluster ccode) 
		estadd local Aidlagged="Yes"
		estadd local FD="Yes"
		estadd local sample="All"
		est store BD_Full2

qui reg d.(gdppcg) dlAid  llShareUNSC dlAID_llUNSC  d.( $bd policy_newper  )   $period $if & Africa==1, vce(cluster ccode) 
		estadd local Aidlagged="Yes"
		estadd local FD="Yes"
		estadd local sample="Africa"
		est store BD_Full3

qui reg d.(gdppcg) dlAid dlAid2 llShareUNSC dlAID_llUNSC  d.( $bd policy_newper  )   $period $if & Africa==1, vce(cluster ccode) 
		estadd local Aidlagged="Yes"
		estadd local FD="Yes"
		estadd local sample="Africa"
		est store BD_Full4

********************************************************
** Table 2: Different timelines
********************************************************
 ***Aid (t)
 
qui reg d.(gdppcg Aid Aid2 $bd policy_newper ) fShareUNSC dAID_fUNSC   $period $if,vce(cluster ccode)
 est store tableBD51
 
qui reg d.(gdppcg Aid Aid2 $bd policy_newper ) ShareUNSC dAID_UNSC   $period $if,vce(cluster ccode)
est store tableBD52
 
qui reg d.(gdppcg Aid Aid2 $bd policy_newper ) lShareUNSC dAID_lUNSC   $period $if,vce(cluster ccode) 
est store tableBD53

qui reg d.(gdppcg Aid Aid2 $bd policy_newper ) llShareUNSC dAID_llUNSC   $period $if,vce(cluster ccode)
est store tableBD54

 ***Aid (t-1)

qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper ) fShareUNSC dlAID_fUNSC   $period $if,vce(cluster ccode)
est store tableBD581
 
qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper ) ShareUNSC dlAID_UNSC   $period $if,vce(cluster ccode)
est store tableBD582 
 
qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper) lShareUNSC dlAID_lUNSC   $period $if,vce(cluster ccode)
est store tableBD583  
 
qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper ) llShareUNSC dlAID_llUNSC   $period $if,vce(cluster ccode)
est store tableBD584

 ***Aid (t-2)

qui reg d.(gdppcg ll.Aid ll.Aid2 $bd policy_newper ) fShareUNSC dllAID_fUNSC   $period $if,vce(cluster ccode)
est store tableBD511

qui reg d.(gdppcg ll.Aid ll.Aid2 $bd policy_newper) ShareUNSC dllAID_UNSC   $period $if,vce(cluster ccode)  
est store tableBD512
  
qui reg d.(gdppcg ll.Aid ll.Aid2 $bd policy_newper) lShareUNSC dllAID_lUNSC   $period $if,vce(cluster ccode) 
est store tableBD513

qui reg d.(gdppcg ll.Aid ll.Aid2 $bd policy_newper) llShareUNSC dllAID_llUNSC   $period $if,vce(cluster ccode)
est store tableBD514

********************************************************
** Table 3 & Table S3.1 & S3.2
********************************************************
*And with dummy
reg d.gdppcg  d.($bd policy_newper ) d.l.Aid d.l.Aid2 dlAID_D_llUNSC D_llUNSC  $period $if,vce(cluster ccode)
est store RTestBD_Dummy
estadd local Aidlagged="Yes"
estadd local FD="Yes"

*With UNSC differenced as well
 qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper  ) dllShareUNSC dlAID_dllUNSC   $period $if,vce(cluster ccode)
est store RTestBD_UNSCD
estadd local Aidlagged="Yes"
estadd local FD="Yes"

*Control variables lagged
qui reg d.(gdppcg l.Aid l.Aid2 l.$bd l.policy_newper ) llShareUNSC dlAID_llUNSC   $period  $if, noc vce(cluster ccode)
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store RTestBD_lagged

*Table 3 & Table S3.3: Early impact aid
reg d.(gdppcg lEarlyaid lEarlyaid2 lrepay_gdp lrepay_gdp2 $bd policy_newper) llShareUNSC dlrepay_gdp_llUNSC  dlEarlyaid_llUNSC $period $if , vce(cluster ccode) 
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store RTestBD_early

*With all ICRG variables 
qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper lvalue1-lvalue13  ) llShareUNSC dlAID_llUNSC   $period $if, cluster(CCode)     //Original
est store RTestBD_ICRG
estadd local Aidlagged="Yes"
estadd local FD="Yes"

*Imports/GDP
qui reg d.(gdppcg) llShareUNSC dlAID_llUNSC  d.( l.Aid l.Aid2 $bd policy_newper l.imports_gdp ) $period $if , vce(cluster ccode)
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store RTestBD_Imports1

*Trade/GDP
qui reg d.(gdppcg) llShareUNSC dlAID_llUNSC  d.( l.Aid l.Aid2 $bd policy_newper l.trade_gdp ) $period $if , vce(cluster ccode)
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store RTestBD_trade1

*FDI/GDP
qui reg d.(gdppcg) llShareUNSC dlAID_llUNSC  d.( l.Aid l.Aid2 $bd policy_newper l.FDIpGDP ) $period $if , vce(cluster ccode)
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store RTestBD_FDI1

*Debt/GNI 
reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper ) llShareUNSC dlAID_llUNSC debt  $period $if,vce(cluster ccode) 
est store RTestBD_debt
estadd local Aidlagged="Yes"
estadd local FD="Yes"

*With UNGA US alignment twice lagged
qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper UNGA_INLINE_US l.UNGA_INLINE_US ll.UNGA_INLINE_US  ) llShareUNSC dlAID_llUNSC   $period $if, cluster(CCode)     //Original
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store RTestBD_UNGA

********************************************************
** Table S3.4: Democracy and Autocracy
********************************************************

qui reg d.(gdppcg l.Aid   $bd policy_newper ) llShareUNSC dlAID_llUNSC   $period $if & llDemocracy==1,vce(cluster ccode) 
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store llDemocracy1

qui reg d.(gdppcg l.Aid $bd policy_newper ) llShareUNSC dlAID_llUNSC   $period $if & llDemocracy==0,vce(cluster ccode) 
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store  llAutocracy1

qui reg d.(gdppcg l.Aid  l.Aid2  $bd policy_newper ) llShareUNSC dlAID_llUNSC   $period $if & llDemocracy==1,vce(cluster ccode) 
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store llDemocracy2

qui  reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper ) llShareUNSC dlAID_llUNSC   $period $if & llDemocracy==0,vce(cluster ccode) 
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store  llAutocracy2

qui reg d.(gdppcg l.Aid  $bd policy_newper ) llShareUNSC dlAID_llUNSC   $period $if & lDemocracy==1,vce(cluster ccode) 
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store lDemocracy1

qui reg d.(gdppcg l.Aid  $bd policy_newper ) llShareUNSC dlAID_llUNSC   $period $if & lDemocracy==0,vce(cluster ccode) 
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store  lAutocracy1

qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper ) llShareUNSC dlAID_llUNSC   $period $if & lDemocracy==1,vce(cluster ccode) 
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store lDemocracy2

qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper ) llShareUNSC dlAID_llUNSC   $period $if & lDemocracy==0,vce(cluster ccode) 
estadd local Aidlagged="Yes"
estadd local FD="Yes"
est store  lAutocracy2
	
	
		
********************************************************
** Table S3.5
********************************************************
		/*Haiti 1977-1997: commitments missing for 6 periods. Therefore, we only have 387 obs. if commitments included but 393 otherwise*/
qui reg d.(gdppcg) llShareUNSC dlAID_llUNSC   d.( l.Aid l.Aid2 $bd policy_newper llAidcom ) $period $if , vce(cluster ccode)
est store Comm1

qui reg d.(gdppcg) llShareUNSC dllComm_llUNSC   d.( llAidcom  $bd policy_newper) $period $if , vce(cluster ccode)
est store Comm2

qui reg d.(gdppcg) llShareUNSC dlAID_llUNSC dllComm_llUNSC  d.( l.Aid  llAidcom  $bd policy_newper ) $period $if , vce(cluster ccode)
est store Comm3

qui reg d.(gdppcg) llShareUNSC dllComm_llUNSC   d.( llAidcom llAidcom2 $bd policy_newper) $period $if , vce(cluster ccode)
est store Comm4

qui reg d.(gdppcg) llShareUNSC dlAID_llUNSC dllComm_llUNSC  d.( l.Aid l.Aid2 llAidcom llAidcom2 $bd policy_newper  ) $period $if , vce(cluster ccode)
est store Comm5

********************************************************
** Table S3.7: Triple interaction
********************************************************
reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper ) llShareUNSC dlAID_llUNSC dlAID2_llUNSC  $period  $if, noc vce(cluster ccode)
est store Triple
estadd local Aidlagged="Yes"
estadd local FD="Yes"
estadd local specification="BD"

**********************************************************************************************************************************************************
* Footnote: Interaction of UNSC membership with need variables
		* Short term debt
		gen dlSTdebt_llUNSC=d.l.STdebt*l2.UNSC
		gen dlSTdebt_llUNSC_dlAID=d.l.STdebt*l2.UNSC*d.l.Aid
		gen dlSTdebt_dlAID=d.l.STdebt*d.l.Aid
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlSTdebt_llUNSC d.( l.Aid l.Aid2 STdebt $bd policy_newper  ) $period $if , vce(cluster ccode)
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlSTdebt_llUNSC dlSTdebt_dlAID dlSTdebt_llUNSC_dlAID d.( l.Aid l.Aid2 STdebt $bd policy_newper  ) $period $if , vce(cluster ccode)
* Debt: Total debt service % of GNI
		gen dldebt_llUNSC=d.l.debt*l2.UNSC
		gen dldebt_llUNSC_dlAID=d.l.debt*l2.UNSC*d.l.Aid
		gen dldebt_dlAID=d.l.debt*d.l.Aid
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dldebt_llUNSC d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dldebt_llUNSC dldebt_dlAID dldebt_llUNSC_dlAID d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)
* Initial GDP per capita
		gen dlgdppc62_0_llUNSC=d.l.gdppc62_0*l2.UNSC
		gen dlgdppc62_0_llUNSC_dlAID=d.l.gdppc62_0*l2.UNSC*d.l.Aid
		gen dlgdppc62_0_dlAID=d.l.gdppc62_0*d.l.Aid
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlgdppc62_0_llUNSC d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlgdppc62_0_llUNSC dlgdppc62_0_dlAID dlgdppc62_0_llUNSC_dlAID d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)
		
* Assassinations
		gen dlassassinations_llUNSC=d.l.assassinations*l2.UNSC
		gen dlassassinations_llUNSC_dlAID=d.l.assassinations*l2.UNSC*d.l.Aid
		gen dlassassinations_dlAID=d.l.assassinations*d.l.Aid
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlassassinations_llUNSC d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlassassinations_llUNSC dlassassinations_dlAID dlassassinations_llUNSC_dlAID d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)		
				
* External conflict: sample size reduced
		gen dlExtConflict_llUNSC=d.l.value5*l2.UNSC
		gen dlExtConflict_llUNSC_dlAID=d.l.value5*l2.UNSC*d.l.Aid
		gen dlExtConflict_dlAID=d.l.value5*d.l.Aid
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlExtConflict_llUNSC d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlExtConflict_llUNSC dlExtConflict_dlAID dlExtConflict_llUNSC_dlAID d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)
* Internal conflict: sample size reduced
		gen dlIntConflict_llUNSC=d.l.value7*l2.UNSC
		gen dlIntConflict_llUNSC_dlAID=d.l.value7*l2.UNSC*d.l.Aid
		gen dlIntConflict_dlAID=d.l.value7*d.l.Aid
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlIntConflict_llUNSC d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlIntConflict_llUNSC dlIntConflict_dlAID dlIntConflict_llUNSC_dlAID d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)	
		

* All need variables
		* Ohne Conflict, da ICRG erst ab 1980
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlgdppc62_0_llUNSC dldebt_llUNSC dlSTdebt_llUNSC dlassassinations_llUNSC d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlgdppc62_0_llUNSC dlgdppc62_0_dlAID dlgdppc62_0_llUNSC_dlAID  dldebt_llUNSC dldebt_dlAID dldebt_llUNSC_dlAID ///
				dlSTdebt_llUNSC dlSTdebt_dlAID dlSTdebt_llUNSC_dlAID dlassassinations_llUNSC dlassassinations_dlAID dlassassinations_llUNSC_dlAID d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)	
		
		* Mit Conflict, da ICRG erst ab 1980
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlgdppc62_0_llUNSC dldebt_llUNSC dlSTdebt_llUNSC dlassassinations_llUNSC dlIntConflict_llUNSC dlExtConflict_llUNSC ///
				d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)
		reg d.(gdppcg) llShareUNSC dlAID_llUNSC  dlgdppc62_0_llUNSC dlgdppc62_0_dlAID dlgdppc62_0_llUNSC_dlAID  dldebt_llUNSC dldebt_dlAID dldebt_llUNSC_dlAID ///
				dlSTdebt_llUNSC dlSTdebt_dlAID dlSTdebt_llUNSC_dlAID dlassassinations_llUNSC dlassassinations_dlAID dlassassinations_llUNSC_dlAID  ///
				dlIntConflict_llUNSC dlIntConflict_dlAID dlIntConflict_llUNSC_dlAID dlExtConflict_llUNSC dlExtConflict_dlAID dlExtConflict_llUNSC_dlAID ///
				d.( l.Aid l.Aid2 debt $bd policy_newper  ) $period $if , vce(cluster ccode)	
	
				
*******************************************************************************************************************************************
* Marginal effects
*******************************************************************************************************************************************

*******************************************************************************************************************************************
		* Figure 5: Marginal effect for main specification with aid squared
******************************************************************************************************************************************
/*
We have to calculate the correct marginal effect for the equation "del Y = o + 1* [Aid(t-1)-Aid(t-2)] + 2*[Aid(t-1)^2 - Aid(t-2)^2)+3*{Aid(t-1)-Aid(t-2)]*UNSC(t-1) +4*X+e"
We do the derivation with respect to del Aid= [Aid(t-1)-Aid(t-2)] 
First expand the equation: "del Y = o + 1* [Aid(t-1)-Aid(t-2)] + 2* [Aid(t-1)+Aid(t-2)] * [Aid(t-1)-Aid(t-2)] + 3*{Aid(t-1)-Aid(t-2)]*UNSC(t-1) +4*X+e"
<= >    "del Y = o + 1* [Aid(t-1)-Aid(t-2)] + 2* [Aid(t-1)- Aid(t-2)+ Aid(t-2)+Aid(t-2)] * [Aid(t-1)-Aid(t-2)] + 3*{Aid(t-1)-Aid(t-2)]*UNSC(t-1) +4*X+e"
<= >    "del Y = o + 1* [del Aid] + 2* [(del Aid)+2*Aid(t-2)] * [del Aid] + 3*{del Aid]*UNSC(t-1) + 4*X+e"
First derivative with respect to del Aid: ME= 1 + 2*2*(del Aid) + 2*2*Aid(t-2)+3*UNSC(t-1)
<= >  ME= 1 + 2*2*(Aid(t-1)-(Aid(t-2)))+2*2*(Aid(t-2))+3*UNSC(t-1)
*/
qui reg d.gdppcg  d.($bd policy_newper ) d.l.Aid d.l.Aid2 c.d.l.Aid#c.llShareUNSC  llShareUNSC  $period $if,vce(cluster ccode)
egen MeanllAid=mean(llAid) if e(sample)
* Graphical depiction of the three marginal effects of aid
predictnl marginal1 = _b[d.l.Aid ]+ _b[d.l.Aid2]*2*(MeanllAid  +d.l.Aid)      +_b[cLD.Aid#c.llShareUNSC]*0 if e(sample)   , se(semarginal1) 
 gen conf11 = marginal1-invttail(367,.95)*semarginal1
 
gen conf12 = marginal1+invttail(367,.95)*semarginal1  // 367 are the degrees of freedom
predictnl marginal2 = _b[d.l.Aid ]+ _b[d.l.Aid2]*2*(MeanllAid  +d.l.Aid)     +_b[cLD.Aid#c.llShareUNSC]*0.25 if e(sample) , se(semarginal2) 
 gen conf21 = marginal2-invttail(367,.95)*semarginal2
gen conf22 = marginal2+invttail(367,.95)*semarginal2
predictnl marginal3 = _b[d.l.Aid ]+ _b[d.l.Aid2]*2*(MeanllAid  +d.l.Aid)      +_b[cLD.Aid#c.llShareUNSC]*0.5 if e(sample), se(semarginal3) 
 gen conf31 = marginal3-invttail(367,.95)*semarginal3
gen conf32 = marginal3+invttail(367,.95)*semarginal3

 twoway    	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) ) ///
			(lfit marginal1   dlAid ,color("black") )  ///
			(lfit marginal2 dlAid   ,color("black") lpattern(dash)) ///
			(lfit marginal3 dlAid  ,color("gs8") lpattern(dash  ))    ///
			if e(sample)  &(dlAid<15 &dlAid>=-10) ,   ylabel(-.5 -0.25 0 0.25 0.5) xlabel(  -10 -5 0  5 10 15 )   graphregion(color(white)) ///
			ytitle("Marginal effect of {&Delta} Aid(t-1) ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of aid ") subtitle( "4-year periods (90% confidence interval)") xsc(r(-10 0   15)) ///
			legend( order(2 "UNSC = 0%" 3 "UNSC = 25%" 4 "UNSC = 50%") ring(6) pos(6) style(zyx2) cols(3) )    
graph save "tables\BDe_MarginalEffect", replace
graph export  "tables\BDe_MarginalEffect.tif", replace
drop  MeanllAid conf*  

*********************************************************************
* Three separate marginal effects
*******************************************************************
	*For non-UNSC members
twoway     	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) ) ///
			(lfit marginal1  dlAid ,color("black") ) ///
			(connected  conf11 dlAid   ,color("gs8")  lpattern(dash )) ///
			(connected  conf12 dlAid  ,color("gs8")  lpattern(dash ))  ///
			if e(sample) &(dlAid<15 &dlAid>=-10) ,   ylabel(-1 -0.5  0  0.5 1) xlabel( -10 -5 0 5 10 15 )    graphregion(color(white)) ///
			ytitle("Marginal effect of {&Delta} Aid (in period t-1)  ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of {&Delta} Aid",color(black)) subtitle(  "(UNSC-Membership = No Member)") xsc(r(-10 0   15))  legend(off) ///
			b1title("4-year periods (90% confidence interval)" , justification(centered) size( small) ) name(panelA,replace)   
graph save "tables\BDe_MarginalEffect1", replace
	
	*For countries that spend 1/4 of a period in the UNSC
twoway    	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) ) ///
			(lfit marginal2   dlAid ,color("black") ) ///
			(connected  conf21 dlAid   ,color("gs8")  lpattern(dash)) ///
			(connected  conf22 dlAid  ,color("gs8")  lpattern(dash))  ///
			if e(sample) &(dlAid<15 &dlAid>=-10)  ,  ylabel( -1 -0.5  0  0.5 1) xlabel( -10 -5 0  5 10 15 )    graphregion(color(white)) ///
			ytitle("Marginal effect of {&Delta} Aid (in period t-1)  ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of {&Delta} Aid",color(black)) subtitle(  "(UNSC-Membership = 1 year)") xsc(r(-10 0   15))  legend(off) ///
			b1title("4-year periods (90% confidence interval)", justification(centered) size( small) ) name(panelB,replace)    
graph save "tables\BDe_MarginalEffect2", replace
				
		*For countries that spend 1/2 period in the UNSC
twoway    	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) ) ///
			(lfit marginal3   dlAid ,color("black") ) ///
			(connected  conf31 dlAid   ,color("gs8") lpattern(dash)) ///
			(connected  conf32 dlAid  ,color("gs8")  lpattern(dash))  ///
			if e(sample) &(dlAid<15 &dlAid>=-10) ,   ylabel( -1 -0.5  0  0.5 1) xlabel(  -10 -5 0  5 10 15 )    graphregion(color(white)) ///
			ytitle("Marginal effect of {&Delta} Aid (in period t-1)  ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of {&Delta} Aid",color(black)) subtitle(  "(UNSC-Membership = 2 years)") xsc(r(-10 0   15))  legend(off) ///
			b1title("4-year periods (90% confidence interval)", justification(centered) size( small) ) name(panelC,replace)  
graph save "tables\BDe_MarginalEffect3", replace

graph combine panelA panelB  panelC,  altshrink scheme( s1mono)  title("Politically motivated aid and growth" "1970-2009", size(medium))  
graph save "tables\Figure 5.gph",replace 
graph export  "tables\Figure 5.tif",  replace  
	drop marginal* semarginal* conf*	
	erase "tables\BDe_MarginalEffect1.gph"
	erase "tables\BDe_MarginalEffect2.gph"
	erase "tables\BDe_MarginalEffect3.gph"	
	
*******************************************************************************************************************************************
		* Figure S3.1: Marginal effect for triple interaction with aid squared
******************************************************************************************************************************************
* Calculate margins with triple interaction
/*
We have to calculate the correct marginal effect for the equation 
"Y(t)-Y(t-1) = o + 1* [Aid(t-1)-Aid(t-2)] + 2*[Aid(t-1)^2 - Aid(t-2)^2)+3*[Aid(t-1)-Aid(t-2)]*UNSC(t-1)+ 4*[Aid(t-1)^2 - Aid(t-2)^2)]*UNSC(t-1)+5*X+e"
We do the derivation with respect to del Aid= [Aid(t-1)-Aid(t-2)] 
First expand the equation: 
		"del Y = o + 1* [Aid(t-1)-Aid(t-2)] + 2*[Aid(t-1)+Aid(t-2)] * [Aid(t-1)-Aid(t-2)] + 3*{Aid(t-1)-Aid(t-2)]*UNSC(t-1) +4*[Aid(t-1)+Aid(t-2)] * [Aid(t-1)-Aid(t-2)]* UNSC + 5*X+e"
<= >    "del Y = o + 1* [Aid(t-1)-Aid(t-2)] + 2* [Aid(t-1)- Aid(t-2)+Aid(t-2)+Aid(t-2)] * [Aid(t-1)-Aid(t-2)] + 3*{Aid(t-1)-Aid(t-2)]*UNSC(t-1) + 4*[Aid(t-1)- Aid(t-2)+Aid(t-2)+Aid(t-2)] * [Aid(t-1)-Aid(t-2)] * UNSC + 5*X+e"
<= >    "del Y = o + 1* [del Aid] + 2* [(del Aid)+2*Aid(t-2)] * [del Aid] + 3*{del Aid]*UNSC(t-1)+ 4* [(del Aid)+2*Aid(t-2)] * [del Aid] * UNSC + 5*X + e"

First derivative with respect to del Aid: ME= 1 + 2*2*(del Aid) + 2*2*Aid(t-2)+ 3*UNSC(t-1) + 2*4*(del Aid)*UNSC + 2*4*Aid(t-2)*UNSC
<= >  ME= 1 + 2*2*(Aid(t-1)-(Aid(t-2)))+2*2*(Aid(t-2))+3*UNSC(t-1) + 2*4*(Aid(t-1)-(Aid(t-2))) * UNSC +2*4*(Aid(t-2))*UNSC
*/

reg d.gdppcg  d.($bd policy_newper ) d.l.Aid d.l.Aid2 c.d.l.Aid#c.llShareUNSC c.d.l.Aid2#c.llShareUNSC   llShareUNSC  $period $if,vce(cluster ccode)
* Graphical depiction of the three marginal effects of aid
predictnl marginal1 = _b[d.l.Aid ]+ _b[d.l.Aid2]*2*(MeanllAid  +d.l.Aid) +_b[cLD.Aid#c.llShareUNSC]*0 + _b[cLD.Aid2#c.llShareUNSC]*2*(MeanllAid+d.l.Aid)*0 if e(sample)   , se(semarginal1) 
 gen conf11 = marginal1-invttail(367,.95)*semarginal1
gen conf12 = marginal1+invttail(367,.95)*semarginal1  // 367 are the degrees of freedom
predictnl marginal2 = _b[d.l.Aid ]+ _b[d.l.Aid2]*2*(MeanllAid  +d.l.Aid) +_b[cLD.Aid#c.llShareUNSC]*0.25 + _b[cLD.Aid2#c.llShareUNSC]*2*(MeanllAid+d.l.Aid)*0.25 if e(sample) , se(semarginal2) 
 gen conf21 = marginal2-invttail(367,.95)*semarginal2
gen conf22 = marginal2+invttail(367,.95)*semarginal2
predictnl marginal3 = _b[d.l.Aid ]+ _b[d.l.Aid2]*2*(MeanllAid  +d.l.Aid) +_b[cLD.Aid#c.llShareUNSC]*0.5 + _b[cLD.Aid2#c.llShareUNSC]*2*(MeanllAid+d.l.Aid)*0.5 if e(sample), se(semarginal3) 
 gen conf31 = marginal3-invttail(367,.95)*semarginal3
gen conf32 = marginal3+invttail(367,.95)*semarginal3 

 twoway    	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) )    (lfit marginal1   dlAid ,color("black") )          (lfit marginal2 dlAid   ,color("black") lpattern(dash)) ///
			(lfit marginal3 dlAid  ,color("gs8") lpattern(dash  ))    ///
			if e(sample)  &(dlAid<15 &dlAid>=-10) ,   graphregion(color(white)) ///
			ytitle("Marginal effect of {&Delta} Aid(t-1) ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of aid, triple interaction ") subtitle( "4-year periods (90% confidence interval)") /*xsc(r(-10 0   15))*/ ///
			legend( order(2 "UNSC = 0%" 3 "UNSC = 25%" 4 "UNSC = 50%") ring(6) pos(6) style(zyx2) cols(3) )    
graph save "tables\BDe_MarginalEffect", replace
graph export "tables\BDe_MarginalEffect_triple.tif", replace 

	*********************************************************************
	*And with three separate marginal effects
	*******************************************************************
	*For non-UNSC members
twoway   	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) ) ///
			(lfit marginal1   dlAid ,color("black") ) ///
			(connected  conf11 dlAid   ,color("gs8")  lpattern(dash )) ///
			(connected  conf12 dlAid  ,color("gs8")  lpattern(dash ))  ///
			if e(sample) &(dlAid<15 &dlAid>=-10) ,   ylabel(-1 -0.5  0  0.5 1) xlabel( -10 -5 0 5 10 15 )    graphregion(color(white)) ///
			ytitle("Marginal effect of {&Delta} Aid (in period t-1)  ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of {&Delta} Aid",color(black)) subtitle(  "(UNSC-Membership = No Member)") xsc(r(-10 0   15))  legend(off) ///
			b1title("4-year periods (90% confidence interval)", justification(centered) size( small) ) name(panelA,replace)   
graph save "tables\BDe_MarginalEffect1_triple", replace
	
	*For countries that spend 1/4 in the UNSC
twoway    	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) ) ///
			(lfit marginal2   dlAid ,color("black") )  ///
			(connected  conf21 dlAid   ,color("gs8")  lpattern(dash)) ///
			(connected  conf22 dlAid  ,color("gs8")  lpattern(dash))  ///
			if e(sample) &(dlAid<15 &dlAid>=-10)  ,   ylabel(-1 -0.5  0  0.5 1) xlabel( -10 -5 0  5 10 15 )    graphregion(color(white)) ///
			ytitle("Marginal effect of {&Delta} Aid (in period t-1)  ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of {&Delta} Aid",color(black)) subtitle(  "(UNSC-Membership = 1/4 period)") xsc(r(-10 0   15))  legend(off) ///
			b1title("4-year periods (90% confidence interval)", justification(centered) size( small) ) name(panelB,replace)    
graph save "tables\BDe_MarginalEffect2_triple", replace
				
		*For countries that spend 1/2 period in the UNSC
twoway    	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) ) ///
			(lfit marginal3   dlAid ,color("black") )   ///
			(connected  conf31 dlAid   ,color("gs8") lpattern(dash)) ///
			(connected  conf32 dlAid  ,color("gs8")  lpattern(dash))  ///
			if e(sample) &(dlAid<15 &dlAid>=-10) ,   ylabel(-1 -0.5  0  0.5 1)  xlabel(  -10 -5 0  5 10 15 )   graphregion(color(white)) ///
			ytitle("Marginal effect of {&Delta} Aid (in period t-1)  ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of {&Delta} Aid",color(black)) subtitle(  "(UNSC-Membership = 1/2 period)") xsc(r(-10 0   15))  legend(off) ///
			b1title("4-year periods (90% confidence interval)", justification(centered) size( small) ) name(panelC,replace)  
graph save "tables\BDe_MarginalEffect3_triple", replace	  

graph combine panelA panelB panelC,  altshrink scheme( s1mono )  title("Burnside and Dollar Specification (19702009)" "including UNSC*aid squared", size(medium))  
graph save "tables\Figure S3_1.gph",replace
graph export "tables\Figure S3_1.tif", replace 
	drop marginal* semarginal* conf*	
	
	erase "tables\BDe_MarginalEffect1_triple.gph"
	erase "tables\BDe_MarginalEffect2_triple.gph"
	erase "tables\BDe_MarginalEffect3_triple.gph"
	
						
*******************************************************************************************************************************************		
			* Figure S3.2: Marginal effect for triple interaction with Africa
*******************************************************************************************************************************************	
	/*
We have to calculate the correct marginal effect for the equation 
"del Y = o + 1* [Aid(t-1)-Aid(t-2)] + 2*[Aid(t-1)^2 - Aid(t-2)^2)+3*{Aid(t-1)-Aid(t-2)]*UNSC(t-1) + 
			4*Africa + 5*[Aid(t-1)-Aid(t-2)]*Africa + 6*[Aid(t-1)^2 - Aid(t-2)^2)*Africa + 7*{Aid(t-1)-Aid(t-2)]*UNSC(t-1)*Africa+8*X+e"
We do the derivation with respect to del Aid= [Aid(t-1)-Aid(t-2)] 
<= >  ME= 1 + 2*2*(Aid(t-1)-(Aid(t-2)))+2*2*(Aid(t-2))+3*UNSC(t-1) + 
			5 *Africa + 2*6*(Aid(t-1)-(Aid(t-2))) * Africa +2*6*(Aid(t-2))*Africa + 7*UNSC(t-1)*Africa
*/
reg d.gdppcg  c.Africa##c.d.($bd policy_newper ) c.Africa##c.d.l.Aid c.Africa##c.d.l.Aid2 c.Africa##c.d.l.Aid#c.llShareUNSC  c.Africa##c.llShareUNSC  $period $if,vce(cluster ccode)
* Graphical depiction of the three marginal effects of aid
predictnl marginal1 =_b[d.l.Aid ]+ _b[d.l.Aid2]*2*(MeanllAid  +d.l.Aid) +_b[cLD.Aid#c.llShareUNSC]*0 + /// 
_b[c.Africa#cLD.Aid] *1 + _b[c.Africa#cLD.Aid2]*2*(MeanllAid  +d.l.Aid) +_b[c.Africa#cLD.Aid#c.llShareUNSC]*0    if e(sample)   , se(semarginal1) 
 gen conf11 = marginal1-invttail(367,.95)*semarginal1
gen conf12 = marginal1+invttail(367,.95)*semarginal1  // 367 are the degrees of freedom

predictnl marginal2 = _b[d.l.Aid ]+ _b[d.l.Aid2]*2*(MeanllAid  +d.l.Aid) +_b[cLD.Aid#c.llShareUNSC]*0.25 + /// 
_b[c.Africa#cLD.Aid] *1 + _b[c.Africa#cLD.Aid2]*2*(MeanllAid  +d.l.Aid) +_b[c.Africa#cLD.Aid#c.llShareUNSC]*0.25   if e(sample)  , se(semarginal2) 
 gen conf21 = marginal2-invttail(367,.95)*semarginal2
gen conf22 = marginal2+invttail(367,.95)*semarginal2

predictnl marginal3 = _b[d.l.Aid ]+ _b[d.l.Aid2]*2*(MeanllAid  +d.l.Aid) +_b[cLD.Aid#c.llShareUNSC]*0.5 + /// 
_b[c.Africa#cLD.Aid] *1 + _b[c.Africa#cLD.Aid2]*2*(MeanllAid  +d.l.Aid) +_b[c.Africa#cLD.Aid#c.llShareUNSC]*0.5    if e(sample), se(semarginal3) 
 gen conf31 = marginal3-invttail(367,.95)*semarginal3
gen conf32 = marginal3+invttail(367,.95)*semarginal3

twoway    	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) )  ///
			(lfit marginal1   dlAid ,color("black") )  ///
			(lfit marginal2 dlAid   ,color("black") lpattern(dash)) ///
			(lfit marginal3 dlAid  ,color("gs8") lpattern(dash  ))    ///
			if e(sample)  &(dlAid<15 &dlAid>=-10) ,  /*ylabel(-.5 -0.25 0 0.25 0.5) xlabel(  -10 -5 0  5 10 15 ) */  graphregion(color(white)) ///
			ytitle("Marginal effect of   {&Delta} Aid(t-1) ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of aid""African countries, subsample") subtitle( "4-year periods (90% confidence interval)") /*xsc(r(-10 0   15))*/ ///
			legend( order(2 "UNSC = 0%" 3 "UNSC = 25%" 4 "UNSC = 50%") ring(6) pos(6) style(zyx2) cols(3) )    
graph save "tables\BDe_MarginalEffect", replace
graph export "tables\BDe_MarginalEffect_africatriple.tif", replace 

	
*********************************************************************
	*And with three separate marginal effects
*******************************************************************
	*For non-UNSC members
twoway    	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) )  ///
			(lfit marginal1   dlAid ,color("black") )  ///
			(connected  conf11 dlAid   ,color("gs8")  lpattern(dash )) ///
			(connected  conf12 dlAid  ,color("gs8")  lpattern(dash ))  ///
			if e(sample) &(dlAid<15 &dlAid>=-10) ,   ylabel(-1 -0.5 0 0.5 1 1.5) xlabel( -10 -5 0 5 10 15 )    graphregion(color(white)) ///
			ytitle("Marginal effect of {&Delta} Aid (in period t-1)  ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of {&Delta} Aid",color(black)) subtitle(  "(UNSC-Membership = No Member)") xsc(r(-10 0   15))  legend(off) ///
			b1title("4-year periods (90% confidence interval)" , justification(centered) size( small) ) name(panelA,replace)   
graph save "tables\BDe_MarginalEffect1_africatriple", replace
	
	*For countries that spend 1/4 in the UNSC
twoway   	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) )  ///
			(lfit marginal2   dlAid ,color("black") ) ///
			(connected  conf21 dlAid   ,color("gs8")  lpattern(dash)) ///
			(connected  conf22 dlAid  ,color("gs8")  lpattern(dash))  ///
			if e(sample) &(dlAid<15 &dlAid>=-10)  ,  ylabel(-1 -0.5 0 0.5 1 1.5) xlabel( -10 -5 0  5 10 15 )    graphregion(color(white)) ///
			ytitle("Marginal effect of {&Delta} Aid (in period t-1)  ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of {&Delta} Aid",color(black)) subtitle(  "(UNSC-Membership = 1/4 period)") xsc(r(-10 0   15))  legend(off) ///
			b1title("4-year periods (90% confidence interval)", justification(centered) size( small) ) name(panelB,replace)    
graph save "tables\BDe_MarginalEffect2_africatriple", replace
	  				
		*For countries that spend 1/2 period in the UNSC
twoway    	(histogram dlAid  , fraction gap(3 ) bin(30) color(gs5) fintensity(inten0) )  ///
			(lfit marginal3   dlAid ,color("black") )   ///
			(connected  conf31 dlAid   ,color("gs8") lpattern(dash)) ///
			(connected  conf32 dlAid  ,color("gs8")  lpattern(dash))  ///
			if e(sample) &(dlAid<15 &dlAid>=-10) ,   ylabel(-1 -0.5 0 0.5 1 1.5) xlabel(  -10 -5 0  5 10 15 )    graphregion(color(white)) ///
			ytitle("Marginal effect of {&Delta} Aid (in period t-1)  ", margin( small )) xtitle("{&Delta} Aid (in period t-1)", margin( small )) yline(0, lwidth( medsmall ) lcolor(black)) ///
			title("Marginal effect of {&Delta} Aid",color(black)) subtitle(  "(UNSC-Membership = 1/2 period)") xsc(r(-10 0   15))  legend(off) ///
			b1title("4-year periods (90% confidence interval)", justification(centered) size(small)) name(panelC,replace)  
graph save "tables\BDe_MarginalEffect3_africatriple", replace
	  
graph combine panelA panelB panelC,  altshrink scheme(s1mono)  title("Burnside and Dollar Specification (19702009)" "Marginal effects for African countries, nested model", size(medium))  
graph save "tables\Figure S3_2.gph",replace
graph export "tables\Figure S3_2.tif", replace 
	drop marginal* semarginal* conf*
	erase "tables\BDe_MarginalEffect1_africatriple.gph"
	erase "tables\BDe_MarginalEffect2_africatriple.gph"
	erase "tables\BDe_MarginalEffect3_africatriple.gph"	
			
***********************************************************************************************************************************************
 ******************** Robustness checks*********************************************************************************************************
preserve
** run preferred regression for e(sample):
qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper  ) llShareUNSC dlAID_llUNSC   $period $if , vce(cluster ccode) 

* check for differential volatility in growth rates of UNSC members vs. no current UNSC members using the variance in growth rates
	cap drop UNSC_variancetest
	gen UNSC_variancetest=0 if ShareUNSCBD==0
	replace UNSC_variancetest=1 if ShareUNSCBD>0 // to test for equality of all UNSC membership countries
	sum gdppcg if UNSC_variancetest==0 & e(sample) //sd:  3.249325
	sum gdppcg if UNSC_variancetest==1 & e(sample) //sd:  3.378754
	bys UNSC_variancetest: sdtest gdppcg == 3.249325 if e(sample) // because 3.249325  is the standard deviation of growth in non-UNSC members
	* no significant difference in growth volatility   
restore
preserve
** check for number of UNSC members that are democratic and autocratic in sample
 qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper ) llShareUNSC dlAID_llUNSC   $period $if & llDemocracy==1, vce(cluster ccode)
 qui reg d.(gdppcg l.Aid l.Aid2 $bd policy_newper ) llShareUNSC dlAID_llUNSC   $period $if & llDemocracy==0, vce(cluster ccode)

tab llDemocracy if e(sample)
keep if e(sample)
restore
preserve
** check for number of never UNSC and at least once UNSC members in the regressions
bys CCode: egen help_member=mean(ShareUNSCBD)
keep if  CCode~="CHN" & CCode~="RUS" & year>1959 & e(sample)
gen member=0
replace member=1 if help_member>0 & help_member!=.
collapse (first) member help_member CCode , by (country)
gen nomember=1 if member==0
egen total_nomember=sum(nomember) // 7
egen total_member=sum(member) //47
sum total_*

******************************************************************************************************************************
** Extended Years Sample RS ***
***************************************************************************************************************************************************************************************************************************************
use "data processed\RS_replicated2.dta",clear
tsset ccode periodendRS,delta(5)
aidstat
quietly{
* Generate Variables within loop
gen Aid = ODA
gen lAid = l.ODA
gen ShareUNSC=ShareUNSCRS

* Generate Aid variables
gen Aid2 = Aid^2
gen lAid2 = l.Aid2
gen dlAid = d.l.Aid
gen dlAid2 = d.l.Aid2
gen llAid = ll.Aid
gen dAid=d.Aid
gen dllAid=d.ll.Aid
gen dAid2 = d.Aid2
gen dllAid2=d.ll.Aid2


** Interaction Terms
gen AID_UNSC=Aid*ShareUNSC 				
label var AID_UNSC "non-lagged Interaction between ODA and share of UNSC membership in period" //disbursements?
gen lShareUNSC=l.ShareUNSC					
labe var  lShareUNSC "share of UNSC membership in period t-1, lagged"
gen llShareUNSC=l.l.ShareUNSC 
label var llShareUNSC "UNSC membership-share in period t-2"
gen lllShareUNSC=l3.ShareUNSC					
labe var  lllShareUNSC "share of UNSC membership in period t-3"
*1.3.1 Aid in t-1 with UNSC in different periods
gen dlAID_lUNSC=dlAid*lShareUNSC			//Interaction  dAid(t-1) * UNSC(t-1)
label var dlAID_lUNSC "Interaction  dAid(t-1) * UNSC(t-1)"
gen dlAID_llUNSC=dlAid*llShareUNSC			//Interaction  dAid(t-1) * UNSC(t-2)
label var dlAID_llUNSC "Interaction  dAid(t-1) * UNSC(t-2)"
gen dlAID_lllUNSC=dlAid*lllShareUNSC			//Interaction  dAid(t-1) * UNSC(t-3)
label var dlAID_lllUNSC "Interaction  dAid(t-1) * UNSC(t-3)"
}
*Conditions from Clemens et al. (2012)
replace rssamp_ab=0 if rssamp_ab==1965
global rs gdppc62_0 life0 open_ww2_0 institution0 lninfl m2final bbfinal revolutions ssa easia geog6099 ethnofrac
global period _Iperiod_2 _Iperiod_3 _Iperiod_4 _Iperiod_5 _Iperiod_6 _Iperiod_7 _Iperiod_8 _Iperiod_9 
global ifd if rssamp_ab==1 & RSsamp62==1 & periodst>=1961
global ifl if rssamp_bb==1 & RSsamp62==1 & periodst>=1961 

***********************************************************************************************
* Table S3.6
***********************************************************************************************
qui  reg d.(gdppcg62  l.Aid $rs   ) llShareUNSC dlAID_llUNSC   $period $ifd, vce(cluster ccode)  
est store RS_C7
estadd local Aidlagged="Yes"
estadd local FD="Yes"

***********************************************************************************************
* Table 3 & Table S3.6
***********************************************************************************************
qui reg d.(gdppcg62  l.Aid l.Aid2 $rs   )llShareUNSC dlAID_llUNSC   $period $ifd, vce(cluster ccode)  
est store RSTable3
estadd local Aidlagged="Yes"
estadd local FD="Yes"

*********************************************************************************************************************************************************************************************************************
************ Descriptive statistics ***************************************************************************************************************************************************************
*********************************************************************************************************************************************************************************************************************
label var ODA "Net ODA"
label var gdppcg62 "GDP p.c. growth"
label var gdppc62_0 "Log Initial GDP/capita"
label var life0 "Initial Life Expectancy"
*label var open_ww2_0 "
label var institution0 "Institutional Quality"
label var geog6099 "Geography"
label var m2final "M2/GDP"
label var bbfinal "Budget Balance"
label var open_ww2_0 "Initial policy"
label var lninfl "Inflation"
label var ethnofrac  "Ethnolinguistic Fractionalization"
qui reg d.(gdppcg62  l.Aid l.Aid2 $rs  )llShareUNSC dlAID_llUNSC   $period $ifd,vce(cluster ccode) 
estpost summarize  gdppcg62 ODA gdppc62_0 institution0 geog6099 revolutions life0 lninfl bbfinal ethnofrac  ///
    open_ww2_0 m2final if e(sample) /* to view on screen */
 	
cap noisily  esttab  using "tables\descriptives log.txt", cells("varlabels(`e(labels)') count mean sd min max") noobs tab label append /* for export */

***********************************************	
* Table 1
***********************************************		
estout 				BD_Full1 BD_Full2 BD_Full3 BD_Full4 using "tables\table 1.txt", replace style(tab)    noabbrev  wrap nolabel title("Main results and results for African sample") ///
					cells(b(star fmt(%9.3f) vacant("-") label(" ")) se(fmt(3) par([ ]) vacant("-") label(" "))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
					stats(Aidlagged FD  r2_a N_clust N , labels("Aid lagged?" "First difference?" "Adj. R-Squared" "Number of countries" "Number of observations"  ) fmt(0 0 3 0 0)) mlabels(none) ///
					keep(dlAid dlAid2 llShareUNSC dlAID_llUNSC D.gdppc62_0 D.assassinations D.ethnicXassass_post D.m2finall1 D.policy_newper) ///
					order(dlAid dlAid2 llShareUNSC dlAID_llUNSC) varlabels(dlAid dAid(t-1) dlAid2 d(Aid(t-1)^2) llShareUNSC UNSC(t-2) dlAID_llUNSC UNSC(t-2)*dAid(t-1)) 
					
***********************************************	
* Table 2
***********************************************	
*Aid(t)
estout 				tableBD51 tableBD52 tableBD53 tableBD54  using "tables\table 2.txt", replace  style(fixed)  noabbrev wrap	nolabel				///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.)))) starlevels(* 0.10 ** 0.05 *** 0.01) ///
					stats(r2_a N_clust N , fmt( 3 0 0) labels( "Adj. R-Squared" "Number of countries" "Number of observations"   )) title("Different timelines")  ///
					mlabels("(1) Aid(t),UNSC(t+1)" "(2)  Aid(t),UNSC(t-t) "  "(3) Aid(t),UNSC(t-1) " "(4) Aid(t),UNSC(t-2) "   ) ///
					keep(dAID_fUNSC dAID_UNSC dAID_lUNSC dAID_llUNSC ) ///
					order(dAID_fUNSC dAID_UNSC dAID_lUNSC dAID_llUNSC ) ///
					varlabels( dAID_UNSC UNSC(t)*Aid(t) ///
					dAID_lUNSC UNSC(t-1)*Aid(t)  dAID_llUNSC UNSC(t-2)*Aid(t)  dAID_fUNSC UNSC(t+1)*Aid(t) ///
					dAID_fUNSC UNSC(t+1)*Aid(t)  ) 
					
*Aid(t-1)		
estout 				tableBD581 tableBD582 tableBD583 tableBD584   using "tables\table 2.txt", append    noabbrev wrap	nolabel				///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.))))  starlevels(* 0.10 ** 0.05 *** 0.01) ///
					stats( r2_a N_clust N , fmt( 3 0 0) labels("Adj. R-Squared" "Number of countries" "Number of observations"   ))   ///
					mlabels("(5) Aid(t-1),UNSC(t+1)" "(6) Aid(t-1),UNSC(t)""(7)  Aid(t-1),UNSC(t-1) "  "(8) Aid(t-1),UNSC(t-2) "  ) ///
					keep( dlAID_fUNSC dlAID_UNSC dlAID_lUNSC dlAID_llUNSC) ///
					order(dlAID_fUNSC dlAID_UNSC dlAID_lUNSC dlAID_llUNSC ) ///
					varlabels( dAID_UNSC UNSC(t)*Aid(t) ///
					dAID_lUNSC UNSC(t-1)*Aid(t)  dAID_llUNSC UNSC(t-2)*Aid(t)  dAID_fUNSC UNSC(t+1)*Aid(t) ///
					dAID_fUNSC UNSC(t+1)*Aid(t)  ) 

*Aid(t-2)				
estout 		  		tableBD511  tableBD512 tableBD513 tableBD514  using "tables\table 2.txt", append    noabbrev wrap	nolabel				///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.))))  starlevels(* 0.10 ** 0.05 *** 0.01) ///
					stats(Aidlagged FD r2_a N_clust N , fmt( 3 0 0) labels( "Adj. R-Squared" "Number of countries" "Number of observations"   ))    ///
					mlabels("(9) Aid(t-2),UNSC(t+1)"  "(10) Aid(t-2),UNSC(t)" "(11)  Aid(t-2),UNSC(t-1) "  "(12) Aid(t-2),UNSC(t-2) "  ) ///
					keep(dllAID_fUNSC dllAID_UNSC dllAID_lUNSC dllAID_llUNSC) ///
					order(dllAID_fUNSC dllAID_UNSC dllAID_lUNSC dllAID_llUNSC) ///
					varlabels( dAID_UNSC UNSC(t)*Aid(t) ///
					dAID_lUNSC UNSC(t-1)*Aid(t)  dAID_llUNSC UNSC(t-2)*Aid(t)  dAID_fUNSC UNSC(t+1)*Aid(t) ///
					dAID_fUNSC UNSC(t+1)*Aid(t)  ) 
					
****************************************************************	
* Table 3 & Table S3.1 & S3.2: Various robustness checks
****************************************************************			
 estout             RTestBD_Dummy	 RTestBD_UNSCD  RTestBD_lagged RTestBD_early  RTestBD_ICRG  RTestBD_Imports1	RTestBD_trade1 RTestBD_FDI1  RTestBD_UNGA  ///
					RTestBD_debt RSTable3 ///
					using "tables\table 3_S3.1_S3.2.txt",replace     noabbrev wrap	nolabel ///
					keep(dlAID_D_llUNSC LD.Aid LD.Aid2 D_llUNSC dllShareUNSC llShareUNSC dlAID_dllUNSC dlAID_llUNSC D.lEarlyaid D.lEarlyaid2 dlEarlyaid_llUNSC) ///
						cells(b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.))) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01) title("Various robustness checks")      ///
					stats(Aidlagged FD r2_a N_clust N , fmt( 0 0 3 0) labels("Aid lagged?" "First difference?" "Adj. R-Squared" "Number of countries" "Number of observations"  ))  ///
					mlabels( "UNSC dummy" "UNSC differenced" "Lagged Explanatory variables" "Early impact aid" "ICRG" "Imports/GDP" "Trade/GDP"  "FDI/GDP" "UNGA" "Debt/GNI" "Rajan and Subramanian" ) 

****************************************************************	
* Table S3.3: Early impact aid
****************************************************************	 
 estout             RTestBD_early  ///
					using "tables\table S3.3.txt",replace   style(fixed)  noabbrev wrap	nolabel ///
					keep( D.lEarlyaid D.lEarlyaid2 llShareUNSC dlEarlyaid_llUNSC) ///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.))))  starlevels(* 0.10 ** 0.05 *** 0.01) title("Early impact aid")      ///
					stats(Aidlagged FD r2_a N_clust N ,fmt(0 0 3 0 0) labels("Aid lagged?" "First difference?" "Adj. R-Squared" "Number of countries" "Number of observations"))  ///
					mlabels( "Early impact aid" ) 	
										
****************************************************************	
* Table S3.4: Democracy and Autocracy
****************************************************************
 estout             llDemocracy1 llAutocracy1  lDemocracy1 lAutocracy1 ///
					using "tables\table S3.4.txt",replace     noabbrev wrap	nolabel ///
					keep(LD.Aid LD.Aid2 llShareUNSC dlAID_llUNSC ) ///
					order(LD.Aid LD.Aid2 llShareUNSC dlAID_llUNSC) varlabels(dlAid dAid(t-1) dlAid2 d(Aid(t-1)^2) llShareUNSC UNSC(t-2) dlAID_llUNSC UNSC(t-2)*dAid(t-1)) ///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.)))) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01) title("Democracy and Autocracy")      ///
					stats(Aidlagged FD r2_a N_clust N ,fmt(0 0 3 0 0) labels("Aid lagged?" "First difference?" "Adj. R-Squared" "Number of countries" "Number of observations" ))  
					
 estout             llDemocracy2 llAutocracy2  lDemocracy2 lAutocracy2  ///
					using "tables\table S3.4.txt",append     noabbrev wrap	nolabel ///
					keep(LD.Aid LD.Aid2 llShareUNSC dlAID_llUNSC ) ///
					order(LD.Aid LD.Aid2 llShareUNSC dlAID_llUNSC) varlabels(dlAid dAid(t-1) dlAid2 d(Aid(t-1)^2) llShareUNSC UNSC(t-2) dlAID_llUNSC UNSC(t-2)*dAid(t-1)) ///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.)))) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01) title("Democracy and Autocracy")      ///
					stats(Aidlagged FD r2_a N_clust N ,fmt(0 0 3 0 0) labels("Aid lagged?" "First difference?" "Adj. R-Squared" "Number of countries" "Number of observations" ))  					
					
****************************************************************	
* Table S3.5: Commitments
****************************************************************		
 estout             Comm1 Comm2 Comm3 Comm4 Comm5  ///
					using "tables\table S3.5.txt", replace   style(fixed)  noabbrev wrap	nolabel ///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.)))) starlevels(* 0.10 ** 0.05 *** 0.01) title("Commitments and disbursements")      ///
					stats(Aidlagged FD r2_a N_clust N ,labels("Aid lagged?" "First difference?" "Adj. R-Squared" "Number of countries" "Number of observations"  ))  ///
					keep(LD.Aid LD.Aid2   D.llAidcom D.llAidcom2  llShareUNSC dlAID_llUNSC dllComm_llUNSC) ///
					order(LD.Aid LD.Aid2   D.llAidcom D.llAidcom2  llShareUNSC dlAID_llUNSC dllComm_llUNSC)			

****************************************************************	
* Table S3.6: Rajan & Subramanian
****************************************************************		
 estout             RS_C7  RSTable3 ///
					using "tables\table S3.6.txt", replace   style(fixed)  noabbrev wrap	nolabel ///
										keep(LD.Aid LD.Aid2 llShareUNSC dlAID_llUNSC ) ///
					order(LD.Aid LD.Aid2 llShareUNSC dlAID_llUNSC) varlabels(dlAid dAid(t-1) dlAid2 d(Aid(t-1)^2) llShareUNSC UNSC(t-2) dlAID_llUNSC UNSC(t-2)*dAid(t-1)) ///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.))))  starlevels(* 0.10 ** 0.05 *** 0.01) title("Rajan & Subramanian")      ///
					stats(Aidlagged FD r2_a  N_clust N,labels("Aid lagged?" "First difference?" "Adj. R-Squared" "Number of countries" "Number of observations"  )) 
						
****************************************************************	
* Table S3.7: Triple interaction
****************************************************************
 estout             Triple using "tables\table S3.7.txt", replace     noabbrev wrap	nolabel ///
					cells((b(star fmt(%9.3f) vacant("-") label(Coef.)) se(fmt(3) par([ ]) vacant("-") label(Std. err.)))) style(tab) starlevels(* 0.10 ** 0.05 *** 0.01) title("Triple interaction")      ///
										keep(LD.Aid LD.Aid2 llShareUNSC dlAID_llUNSC dlAID2_llUNSC  ) ///
					order(LD.Aid LD.Aid2 llShareUNSC dlAID_llUNSC dlAID2_llUNSC ) varlabels(dlAid dAid(t-1) dlAid2 d(Aid(t-1)^2) llShareUNSC UNSC(t-2) dlAID_llUNSC UNSC(t-2)*dAid(t-1)) ///
					stats(Aidlagged FD r2_a  N_clust N,labels("Aid lagged?" "First difference?" "Adj. R-Squared" "Number of countries" "Number of observations"  )) 
						
estimates drop _all
 window manage close graph _all
 
****************************************************************	
* Table S5.1 & Table S5.2
****************************************************************
* Sectoral disaggregation using the OECD's CRS Data
use "data processed\CRSaid_unsc.dta", clear
sectoral

************************************************************************************************************************
*Descriptives for referee questions
************************************************************************************************************************
insheet using  "total aid commitments by country DAC 3a_incl multi.csv", nodouble comma clear
drop if strmatch(v2, "*Total") | strmatch(v2, "*regional")
keep if v4=="DAC Countries, Total"
rename value bilateral
keep if v8=="Total Commitments"
duplicates list v2 year
save "data processed\DAC_biODA.dta", replace
************************************************************************************************************************
insheet using  "total aid commitments by country DAC 3a_incl multi.csv", nodouble comma clear
drop if strmatch(v2, "*Total") | strmatch(v2, "*regional")
keep if v4=="Multilateral, Total"
keep if v8=="Total Commitments"
rename value multilateral
save "data processed\DAC_multiODA.dta", replace
merge 1:1 v2 year using "data processed\DAC_biODA.dta", nogen keep (3)
rename  v2 country
merge m:1 country using "data processed\codes_processed.dta", nogen keep (3)
save "data processed\BD_Extension_descriptives.dta", replace
*************************************************************************************************************************
use "data processed\CRSaid_unsc.dta", clear
collapse (first) recipientname recipientcode (sum)  usd_commitment usd_disbursement usd_commitment_defl usd_received usd_disbursement_defl usd_received_defl, by (CODE year)
rename CODE code
merge 1:1 code year using "data processed\BD_Extension_descriptives.dta" 
gen ODA=multilateral+bilateral
gen reported_share=usd_commitment/ODA
gen reported_share_bi=usd_commitment/bilateral
